@@ -3,9 +3,6 @@
 //! the size of physical memory pages into bytes, and bytes into the number of physical memory
 //! pages.
 //!
-//! Currently, this crate only supports Rust nightly version because of using
-//! [`const_fn`](https://doc.rust-lang.org/beta/unstable-book/language-features/const-fn.html) feature.
-//!
 //! # Examples
 //!
 //! ```rust
@@ -21,8 +18,7 @@
 //! ```
 #![cfg_attr(not(test), no_std)]
 #![deny(
-    warnings,
-    rustdoc,
+    rustdoc::all,
     missing_docs,
     elided_lifetimes_in_paths,
     explicit_outlives_requirements,
